# SCEMATK: Single Cell Extraction and Morphological Analysis Toolkit

Hello and welcome to scematk, a Python package for processing whole slide images (WSI's) and extracting morphological profiles of cells at a single cell resolution.

This package is currently under heavy development and is not yet ready for public use. Please check back later for updates.
